@@ -106,11 +106,14 @@ gboolean            visit_rc_directory_sync       (const char       *rc_dir,
 
 gboolean	    mime_type_is_image	          (const char       *mime_type);
 gboolean            mime_type_is_video            (const char       *mime_type);
+gboolean            mime_type_is_audio            (const char       *mime_type);
 gboolean	    file_is_image 		  (const gchar      *name,
 						   gboolean          fast_file_type);
 gboolean            file_is_video                 (const gchar      *name,
                                                    gboolean          fast_file_type);
-gboolean            file_is_image_or_video        (const gchar      *name,
+gboolean            file_is_audio                 (const gchar      *name,
+                                                   gboolean          fast_file_type);
+gboolean            file_is_image_video_or_audio  (const gchar      *name,
                                                    gboolean          fast_file_type);
 gboolean            file_is_hidden                (const char       *name);
 gboolean            file_copy                     (const char       *from,
@@ -146,6 +149,8 @@ const char *        get_catalog_path_from_uri     (const char       *uri);
 const char *        get_search_path_from_uri      (const char       *uri);
 const char *        remove_scheme_from_uri        (const char       *uri);
 char *              get_uri_scheme                (const char       *uri);
+const char *        remove_host_from_uri          (const char       *uri);
+char *              get_uri_host                  (const char       *uri);
 char *              get_base_uri                  (const char       *uri);
 gboolean            uri_has_scheme                (const char       *uri);
 gboolean            uri_scheme_is_file            (const char       *uri);
@@ -244,4 +249,7 @@ GdkPixbufAnimation* gth_pixbuf_animation_new_from_uri (const char            *fi
 						       gint	              requested_height_if_used,
 						       GnomeThumbnailFactory *factory,
 						       const char            *mime_type);
+
+char *              xdg_user_dir_lookup               (const char            *type);
+
 #endif /* FILE_UTILS_H */
