@@ -44,7 +44,6 @@
 #include "file-utils.h"
 #include "gconf-utils.h"
 #include "glib-utils.h"
-#include "jpeg-utils.h"
 #include "gthumb-marshal.h"
 
 #define DEFAULT_MAX_FILE_SIZE (4*1024*1024)
@@ -65,6 +64,7 @@ struct _ThumbLoaderPrivateData
 
 	char *uri;
 	const char *mime_type;
+	time_t mtime;
 
 	gboolean use_cache : 1;
 	gboolean from_cache : 1;
@@ -197,6 +197,7 @@ thumb_loader_init (ThumbLoader *tl)
 	priv->from_cache = FALSE;
 	priv->percent_done = 0.0;
 	priv->max_file_size = 0;
+	priv->mtime = 0;
 }
 
 
@@ -328,19 +329,6 @@ thumb_loader_set_max_file_size (ThumbLoader      *tl,
 }
 
 
-GnomeVFSFileSize
-thumb_loader_get_max_file_size (ThumbLoader      *tl)
-{
-	ThumbLoaderPrivateData *priv;
-
-	g_return_val_if_fail (tl != NULL, 0);
-
-	priv = tl->priv;
-
-	return priv->max_file_size;
-}
-
-
 void
 thumb_loader_set_path (ThumbLoader *tl,
 		       const char  *path,
@@ -361,34 +349,6 @@ thumb_loader_set_path (ThumbLoader *tl,
 }
 
 
-void
-thumb_loader_set_uri (ThumbLoader       *tl,
-		      const GnomeVFSURI *vfs_uri,
-		      const char        *mime_type)
-{
-	ThumbLoaderPrivateData *priv;
-
-	g_return_if_fail (tl != NULL);
-	g_return_if_fail (vfs_uri != NULL);
-
-	priv = tl->priv;
-	g_free (priv->uri);
-
-	priv->uri = gnome_vfs_uri_to_string (vfs_uri, GNOME_VFS_URI_HIDE_NONE);
-	tl->priv->mime_type = mime_type;
-
-	image_loader_set_uri (priv->il, vfs_uri, mime_type);
-}
-
-
-GnomeVFSURI *
-thumb_loader_get_uri (ThumbLoader *tl)
-{
-	g_return_val_if_fail (tl != NULL, NULL);
-	return new_uri_from_path (tl->priv->uri);
-}
-
-
 GdkPixbuf *
 thumb_loader_get_pixbuf (ThumbLoader *tl)
 {
@@ -396,27 +356,7 @@ thumb_loader_get_pixbuf (ThumbLoader *tl)
 	return tl->priv->pixbuf;
 }
 
-
-ImageLoader *
-thumb_loader_get_image_loader (ThumbLoader *tl)
-{
-	g_return_val_if_fail (tl != NULL, NULL);
-	return tl->priv->il;
-}
-
-
-char *
-thumb_loader_get_path (ThumbLoader *tl)
-{
-	g_return_val_if_fail (tl != NULL, NULL);
-
-	if (tl->priv->uri == NULL)
-		return NULL;
-
-	return g_strdup (tl->priv->uri);
-}
-
-
+	
 static void
 thumb_loader_start__step2 (ThumbLoader *tl)
 {
@@ -428,20 +368,25 @@ thumb_loader_start__step2 (ThumbLoader *tl)
 	priv = tl->priv;
 
 	g_return_if_fail (priv->uri != NULL);
+	
+	priv->mtime = get_file_mtime (priv->uri);
 
 	if (priv->use_cache) {
-		time_t  mtime;
-
-		mtime = get_file_mtime (priv->uri);
-
+		
 		cache_path = gnome_thumbnail_factory_lookup (priv->thumb_factory,
 							     priv->uri,
-							     mtime);
+							     priv->mtime);
 
-		if ((cache_path == NULL)
-		    && gnome_thumbnail_factory_has_valid_failed_thumbnail (priv->thumb_factory,
-									   priv->uri,
-									   mtime)) {
+		if ((cache_path == NULL) &&
+		    ((time (NULL) - priv->mtime) > (time_t) 5) &&
+		    gnome_thumbnail_factory_has_valid_failed_thumbnail (priv->thumb_factory,
+									priv->uri,
+									priv->mtime)) {
+			/* Use the existing "failed" thumbnail, if it is over
+			   5 seconds old. Otherwise, try to thumbnail it again. 
+			   The minimum age requirement addresses bug 432759, 
+			   which occurs when a device like a scanner saves a file
+			   slowly in chunks. */
 			g_signal_emit (G_OBJECT (tl),
 				       thumb_loader_signals[THUMB_ERROR],
 				       0);
@@ -505,9 +450,10 @@ static gint
 thumb_loader_save_to_cache (ThumbLoader *tl)
 {
 	ThumbLoaderPrivateData *priv;
-	time_t                  mtime;
 	char                   *cache_dir;
 	char                   *cache_path;
+	char		       *uri_path = NULL;
+	char                   *uri_dir = NULL;
 
 	if (tl == NULL)
 		return FALSE;
@@ -516,8 +462,6 @@ thumb_loader_save_to_cache (ThumbLoader *tl)
 	if (priv->pixbuf == NULL)
 		return FALSE;
 
-	mtime = get_file_mtime (priv->uri);
-
 	cache_path = gnome_thumbnail_path_for_uri (priv->uri, GNOME_THUMBNAIL_SIZE_NORMAL);
 	cache_dir = remove_level_from_path (cache_path);
 	g_free (cache_path);
@@ -525,11 +469,25 @@ thumb_loader_save_to_cache (ThumbLoader *tl)
 	if (cache_dir == NULL)
 		return FALSE;
 
+	if (is_local_file (priv->uri)) {
+		uri_path = gnome_vfs_get_local_path_from_uri (priv->uri);
+		uri_dir = remove_level_from_path (uri_path);
+		g_free (uri_path);
+
+		/* Do not save thumbnails from the user's thumbnail directory,
+		   or an endless loop of thumbnailing may be triggered. */
+		if (strcmp_null_tollerant (cache_dir, uri_dir) == 0) {
+			g_free (uri_dir);	
+			return FALSE;
+		}
+		g_free (uri_dir);
+	}
+
 	if (ensure_dir_exists (cache_dir, THUMBNAIL_DIR_PERMISSIONS))
 		gnome_thumbnail_factory_save_thumbnail (priv->thumb_factory,
 							priv->pixbuf,
 							priv->uri,
-							mtime);
+							priv->mtime);
 
 	g_free (cache_dir);
 
@@ -557,7 +515,7 @@ thumb_loader_done_cb (ImageLoader *il,
 	if (pixbuf == NULL) {
 		gnome_thumbnail_factory_create_failed_thumbnail (priv->thumb_factory,
 								 priv->uri,
-								 get_file_mtime (priv->uri));
+								 priv->mtime);
 		g_signal_emit (G_OBJECT (tl), thumb_loader_signals[THUMB_ERROR], 0);
 		return;
 	}
@@ -604,7 +562,8 @@ thumb_loader_done_cb (ImageLoader *il,
 								GDK_INTERP_BILINEAR);
 			g_object_unref (pixbuf);
 		}
-	} else {
+	} 
+	else {
 		modified = scale_keepping_ratio (&width, &height, priv->max_w, priv->max_h);
 		if (modified) {
 			g_object_unref (priv->pixbuf);
@@ -634,7 +593,8 @@ thumb_loader_error_cb (ImageLoader *il,
 
 		gnome_thumbnail_factory_create_failed_thumbnail (priv->thumb_factory,
 								 priv->uri,
-								 get_file_mtime (priv->uri));
+								 priv->mtime);
+
 		g_signal_emit (G_OBJECT (tl), thumb_loader_signals[THUMB_ERROR], 0);
 
 		return;
