@@ -26,7 +26,7 @@
 #include <glib.h>
 #include <gtk/gtk.h>
 #include <gtk/gtkenums.h> /* for GtkSortType */
-#include "gthumb-window.h"
+#include "gth-window.h"
 #include "image-loader.h"
 #include "typedefs.h"
 
@@ -46,7 +46,7 @@ struct _CatalogWebExporter {
 
 	/*< private >*/
 
-	GThumbWindow *window;
+	GthWindow    *window;
 
 	GList        *file_list;              /* char* elements. */
 	GList        *album_files;
@@ -58,6 +58,7 @@ struct _CatalogWebExporter {
 	int           page_rows;              /* Number of rows and columns
 	 				       * each page must have. */
 	int           page_cols;
+	gboolean      single_index;
 
 	char         *tmp_location;
 	char         *location;               /* Save files in this 
@@ -125,7 +126,7 @@ struct _CatalogWebExporterClass {
 
 GType      catalog_web_exporter_get_type              (void);
 
-CatalogWebExporter *  catalog_web_exporter_new        (GThumbWindow       *window,
+CatalogWebExporter *  catalog_web_exporter_new        (GthWindow          *window,
 						       GList              *file_list);
 
 void       catalog_web_exporter_set_header            (CatalogWebExporter *ce,
@@ -171,6 +172,9 @@ void       catalog_web_exporter_set_row_col           (CatalogWebExporter *ce,
 						       int                 rows,
 						       int                 cols);
 
+void       catalog_web_exporter_set_single_index      (CatalogWebExporter *ce,
+						       gboolean            copy);
+
 void       catalog_web_exporter_set_image_caption     (CatalogWebExporter *ce,
 						       GthCaptionFields    caption);
 
