@@ -33,6 +33,7 @@
 #include "gth-pixbuf-op.h"
 #include "gth-window.h"
 #include "gthumb-stock.h"
+#include "glib-utils.h"
 #include "pixbuf-utils.h"
 
 
@@ -48,7 +49,9 @@ typedef struct {
 	GdkPixbuf    *orig_pixbuf;
 	GdkPixbuf    *new_pixbuf;
 
+	GthPixbufOp  *pixop;
 	gboolean      modified;
+	gboolean      dialog_preview;
 
 	GladeXML     *gui;
 
@@ -65,6 +68,12 @@ static void
 destroy_cb (GtkWidget  *widget,
 	    DialogData *data)
 {
+	if (data->pixop != NULL) {
+		if (data->dialog_preview)
+			g_signal_handlers_disconnect_by_data (data->pixop, data);
+		gth_pixbuf_op_stop (data->pixop);
+		g_object_unref (data->pixop);
+	}
 	g_object_unref (data->image);
 	g_object_unref (data->orig_pixbuf);
 	g_object_unref (data->new_pixbuf);
@@ -78,8 +87,11 @@ preview_done_cb (GthPixbufOp *pixop,
 		 gboolean     completed,
 		 DialogData  *data)
 {
-	gtk_widget_queue_draw (data->bc_preview_image);
-	g_object_unref (pixop);
+	if (completed)
+		gtk_widget_queue_draw (data->bc_preview_image);
+	g_object_unref (data->pixop);
+	data->pixop = NULL;
+
 	return FALSE;
 }
 
@@ -91,31 +103,35 @@ apply_changes (DialogData *data,
 	       gboolean    dialog_preview,
 	       gboolean    window_preview)
 {
-	double       hue;
-	double       lightness;
-	double       saturation;
-	GthPixbufOp *pixop;
+	double hue;
+	double lightness;
+	double saturation;
+
+	if (data->pixop != NULL) {
+		gth_pixbuf_op_stop (data->pixop);
+		g_object_unref (data->pixop);
+	}
 
 	hue = gtk_range_get_value (GTK_RANGE (data->bc_hue_hscale));
 	lightness = gtk_range_get_value (GTK_RANGE (data->bc_lightness_hscale));
 	saturation = gtk_range_get_value (GTK_RANGE (data->bc_saturation_hscale));
 
-	pixop = _gdk_pixbuf_hue_lightness_saturation (src,
-						      dest,
-						      hue,
-						      lightness,
-						      saturation);
+	data->pixop = _gdk_pixbuf_hue_lightness_saturation (src,
+							    dest,
+							    hue,
+							    lightness,
+							    saturation);
 
+	data->dialog_preview = dialog_preview;
 	if (dialog_preview) {
-		g_signal_connect (G_OBJECT (pixop),
+		g_signal_connect (G_OBJECT (data->pixop),
 				  "pixbuf_op_done",
 				  G_CALLBACK (preview_done_cb),
 				  data);
-		gth_pixbuf_op_start (pixop);
-	} else {
-		gth_window_exec_pixbuf_op (data->window, pixop, window_preview);
-		g_object_unref (pixop);
+		gth_pixbuf_op_start (data->pixop);
 	}
+	else
+		gth_window_exec_pixbuf_op (data->window, data->pixop, window_preview);
 }
 
 
